"""
Copyright 2021-2023 MICRORISC s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from dataclasses import dataclass
import json


@dataclass
class GatewayMeasurement:
	"""A class representing a gateway measurement."""

	__slots__ = 'gw_id', 'name', 'value'

	gw_id: str
	name: str
	value: float

	def __repr__(self) -> str:
		"""
		Serialize entity into JSON string.

		Returns:
			str: JSON-serialized entity string
		"""
		return json.dumps(self.serialize())

	def serialize(self) -> dict:
		"""
		Serialize gateway measurement entity to InfluxDB compatible format.

		Returns:
			dict: JSON-serialized gateway measurement entity
		"""
		return {
			'measurement': self.name,
			'tags': {
				'gwId': f'gw_{self.gw_id}'.lower(),
				'valid': self.value is not None,
			},
			'fields': {
				'value': self.value if self.value is not None else 0.0
			}
		}
